summaryrefslogtreecommitdiffstats
path: root/kradio3/plugins/gui-quickbar/buttonflowlayout.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-15 15:32:31 -0600
committerTimothy Pearson <[email protected]>2011-12-15 15:32:31 -0600
commit5fb78f4b68672906005b059e7e5066c702bc5c90 (patch)
tree715819ae8220ea037525fe5d7f15f7879c137b88 /kradio3/plugins/gui-quickbar/buttonflowlayout.h
parentb66ecc4a25ee7b26513ffe3c91ffbed7fe313a0d (diff)
downloadtderadio-5fb78f4b68672906005b059e7e5066c702bc5c90.tar.gz
tderadio-5fb78f4b68672906005b059e7e5066c702bc5c90.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kradio3/plugins/gui-quickbar/buttonflowlayout.h')
-rw-r--r--kradio3/plugins/gui-quickbar/buttonflowlayout.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kradio3/plugins/gui-quickbar/buttonflowlayout.h b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
index fe33efc..3346c6d 100644
--- a/kradio3/plugins/gui-quickbar/buttonflowlayout.h
+++ b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
@@ -1,7 +1,7 @@
/****************************************************************************
-** $Id: buttonflowtqlayout.h 471 2006-11-11 17:04:51Z emw $
+** $Id: buttonflowlayout.h 471 2006-11-11 17:04:51Z emw $
**
-** Definition of simple flow tqlayout for custom tqlayout example
+** Definition of simple flow layout for custom layout example
**
** Created : 979899
**
@@ -23,7 +23,7 @@
#include "../../src/include/utils.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqptrlist.h>
class ButtonFlowLayout : public TQLayout
@@ -41,9 +41,9 @@ public:
void addItem( TQLayoutItem *item);
bool hasHeightForWidth() const;
int heightForWidth( int ) const;
- TQSize tqsizeHint() const;
- TQSize tqminimumSize() const;
- TQSize tqminimumSize(const TQSize &r) const; // tqminimumSize is dependent from width
+ TQSize sizeHint() const;
+ TQSize minimumSize() const;
+ TQSize minimumSize(const TQSize &r) const; // minimumSize is dependent from width
TQLayoutIterator iterator();
TQSizePolicy::ExpandData expanding() const;